@@ -11,8 +11,14 @@ from .shared import (
     validate_list_duplicate_values
 )
 from .input import validate_must_include_id, validate_input_country
-from .practice import validate_cropResidueManagement, validate_longFallowPeriod, validate_excretaManagement
-from .product import validate_economicValueShare, validate_value as validate_product_value, validate_excreta
+from .practice import (
+    validate_cropResidueManagement, validate_longFallowPeriod, validate_excretaManagement, validate_no_tillage,
+    validate_tillage_site_type, validate_tillage_values
+)
+from .product import (
+    validate_economicValueShare, validate_value as validate_product_value, validate_excreta,
+    validate_primary as validate_product_primary
+)
 from .data_completeness import validate_dataCompleteness
 from .transformation import (
     validate_previous_transformation, validate_first_transformation, validate_transformation_excretaManagement
@@ -203,6 +209,7 @@ def validate_cycle(cycle: dict, node_map: dict = {}):
         validate_economicValueShare(cycle.get('products')),
         validate_sum_aboveGroundCropResidue(cycle.get('products')),
         validate_product_value(cycle.get('products')),
+        validate_product_primary(cycle.get('products')),
         validate_properties_default_value(cycle, 'products'),
         validate_properties_valueType(cycle, 'products'),
         validate_crop_residue_completeness(cycle, site) if 'dataCompleteness' in cycle and site else True,
@@ -219,7 +226,10 @@ def validate_cycle(cycle: dict, node_map: dict = {}):
         validate_properties_default_value(cycle, 'practices'),
         validate_properties_valueType(cycle, 'practices'),
         validate_list_duplicate_values(cycle, 'practices', 'term.termType', TermTermType.EXCRETAMANAGEMENT.value),
-        validate_excretaManagement(cycle, cycle.get('practices'))
+        validate_excretaManagement(cycle, cycle.get('practices')),
+        validate_no_tillage(cycle.get('practices')),
+        validate_tillage_site_type(cycle.get('practices'), site),
+        validate_tillage_values(cycle.get('practices'))
     ] if len(cycle.get('practices', [])) > 0 else []) + flatten([
         validate_functionalUnit(cycle, site)
     ] if 'functionalUnit' in cycle and site else []) + flatten([
