@@ -3,7 +3,8 @@ from hestia_earth.utils.model import find_term_match
 from hestia_earth.utils.lookup import download_lookup, get_table_value, column_name
 from hestia_earth.utils.tools import non_empty_list
 
-from hestia_earth.validation.utils import _filter_list_errors
+from hestia_earth.validation.utils import _filter_list_errors, update_error_path
+from .shared import validate_country
 
 MUST_INCLUDE_ID_COL = column_name('mustIncludeId')
 MUST_INCLUDE_ID_TERM_TYPES = [
@@ -32,3 +33,13 @@ def validate_must_include_id(inputs: list):
         }
 
     return _filter_list_errors(map(validate, enumerate(inputs)))
+
+
+def validate_input_country(node: dict, list_key: list):
+    def validate(values: tuple):
+        index, input = values
+        country = input.get('country')
+        error = country is None or validate_country(input)
+        return error is True or update_error_path(error, list_key, index)
+
+    return _filter_list_errors(map(validate, enumerate(node.get(list_key, []))))
