@@ -1,5 +1,4 @@
 from unittest.mock import patch
-
 import json
 
 from tests.utils import fixtures_path
@@ -28,6 +27,14 @@ def test_validate_characterisedIndicator_model_invalid(*args):
         'dataPath': '.impacts[0].methodModel.@id',
         'message': 'is not allowed for this characterisedIndicator',
         'params': {
+            'term': {
+                '@type': 'Term',
+                '@id': 'gwp20'
+            },
+            'model': {
+                '@type': 'Term',
+                '@id': 'ipcc2013'
+            },
             'allowedValues': models
         }
     }
