@@ -1,7 +1,9 @@
 import json
 
 from tests.utils import fixtures_path
-from hestia_earth.validation.validators.product import validate_economicValueShare, validate_value, validate_excreta
+from hestia_earth.validation.validators.product import (
+    validate_economicValueShare, validate_value, validate_excreta, validate_primary
+)
 
 
 def test_validate_economicValueShare_valid():
@@ -80,3 +82,22 @@ def test_validate_excreta_warning():
             'expected': 'excretaPoultryKgN'
         }
     }
+
+
+def test_validate_primary_valid():
+    # no products should be valid
+    assert validate_primary([])
+
+    with open(f"{fixtures_path}/product/primary/valid.json") as f:
+        data = json.load(f)
+    assert validate_primary(data.get('nodes')) is True
+
+
+def test_validate_primary_error():
+    with open(f"{fixtures_path}/product/primary/invalid.json") as f:
+        data = json.load(f)
+    assert validate_primary(data.get('nodes')) == {
+        'level': 'error',
+        'dataPath': '.products',
+        'message': 'only 1 primary product allowed'
+    }
